from setuptools import setup

setup(name='tj_probability_package',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['tj_probability_package'],
      author = "Akintayo Jabar",
      author_email = "tayojabar@gmail.com",
      zip_safe=False)
